==> pyanilist-0.3.1-py3-none-any.whl: pyanilist/__init__.py <==
from ._clients import Anilist, AsyncAnilist
from ._enums import (
    CharacterRole,
    ExternalLinkType,
    MediaFormat,
    MediaRankType,
    MediaRelation,
    MediaSeason,
    MediaSource,
    MediaStatus,
    MediaType,
)
from ._exceptions import (
    CloseError,
    ConnectError,
    ConnectTimeout,
    CookieConflict,
    DecodingError,
    HTTPError,
    HTTPStatusError,
    InvalidURL,
    LocalProtocolError,
    NetworkError,
    PoolTimeout,
    ProtocolError,
    ProxyError,
    ReadError,
    ReadTimeout,
    RemoteProtocolError,
    RequestError,
    RequestNotRead,
    ResponseNotRead,
    StreamClosed,
    StreamConsumed,
    StreamError,
    TimeoutException,
    TooManyRedirects,
    UnsupportedProtocol,
    ValidationError,
    WriteError,
    WriteTimeout,
)
from ._models import (
    AiringSchedule,
    Character,
    CharacterImage,
    CharacterName,
    FuzzyDate,
    Media,
    MediaCoverImage,
    MediaExternalLink,
    MediaRank,
    MediaStreamingEpisode,
    MediaTag,
    MediaTitle,
    MediaTrailer,
    Relation,
    Staff,
    StaffImage,
    StaffName,
    Studio,
)
from ._types import AnilistID, AnilistTitle, AnilistYear, Color, CountryCode, HttpUrl, YearsActive
from ._version import _get_version

__version__ = _get_version()
__version_tuple__ = tuple(__version__.split("."))

__all__ = [
    # Clients
    "AsyncAnilist",
    "Anilist",
    # Enums
    "CharacterRole",
    "ExternalLinkType",
    "MediaFormat",
    "MediaRankType",
    "MediaRelation",
    "MediaSeason",
    "MediaSource",
    "MediaStatus",
    "MediaType",
    # Types
    "AnilistID",
    "AnilistTitle",
    "AnilistYear",
    "Color",
    "CountryCode",
    "HttpUrl",
    "YearsActive",
    # Models
    "AiringSchedule",
    "Character",
    "CharacterImage",
    "CharacterName",
    "FuzzyDate",
    "Media",
    "MediaCoverImage",
    "MediaExternalLink",
    "MediaRank",
    "MediaStreamingEpisode",
    "MediaTag",
    "MediaTitle",
    "MediaTrailer",
    "Relation",
    "Staff",
    "StaffImage",
    "StaffName",
    "Studio",
    # Exceptions
    "CloseError",
    "ConnectError",
    "ConnectTimeout",
    "CookieConflict",
    "DecodingError",
    "HTTPError",
    "HTTPStatusError",
    "InvalidURL",
    "LocalProtocolError",
    "NetworkError",
    "PoolTimeout",
    "ProtocolError",
    "ProxyError",
    "ReadError",
    "ReadTimeout",
    "RemoteProtocolError",
    "RequestError",
    "RequestNotRead",
    "ResponseNotRead",
    "StreamClosed",
    "StreamConsumed",
    "StreamError",
    "TimeoutException",
    "TooManyRedirects",
    "UnsupportedProtocol",
    "WriteError",
    "WriteTimeout",
    "ValidationError",
]

==> pyanilist-0.4.1-py3-none-any.whl: pyanilist/__init__.py <==
from ._clients import AniList, AsyncAniList
from ._enums import (
    CharacterRole,
    ExternalLinkType,
    MediaFormat,
    MediaRankType,
    MediaRelation,
    MediaSeason,
    MediaSource,
    MediaStatus,
    MediaType,
)
from ._exceptions import (
    CloseError,
    ConnectError,
    ConnectTimeout,
    CookieConflict,
    DecodingError,
    HTTPError,
    HTTPStatusError,
    InvalidURL,
    LocalProtocolError,
    NetworkError,
    PoolTimeout,
    ProtocolError,
    ProxyError,
    ReadError,
    ReadTimeout,
    RemoteProtocolError,
    RequestError,
    RequestNotRead,
    ResponseNotRead,
    StreamClosed,
    StreamConsumed,
    StreamError,
    TimeoutException,
    TooManyRedirects,
    UnsupportedProtocol,
    ValidationError,
    WriteError,
    WriteTimeout,
)
from ._models import (
    AiringSchedule,
    Character,
    CharacterImage,
    CharacterName,
    FuzzyDate,
    Media,
    MediaCoverImage,
    MediaDescription,
    MediaExternalLink,
    MediaRank,
    MediaStreamingEpisode,
    MediaTag,
    MediaTitle,
    MediaTrailer,
    Relation,
    Staff,
    StaffImage,
    StaffName,
    Studio,
)
from ._types import AniListID, AniListTitle, AniListYear, Color, CountryCode, HttpUrl, YearsActive
from ._version import VersionInfo, _get_version

__version__ = _get_version()
__version_tuple__ = VersionInfo(*map(int, __version__.split(".")))

__all__ = [
    # Clients
    "AsyncAniList",
    "AniList",
    # Enums
    "CharacterRole",
    "ExternalLinkType",
    "MediaFormat",
    "MediaRankType",
    "MediaRelation",
    "MediaSeason",
    "MediaSource",
    "MediaStatus",
    "MediaType",
    # Types
    "AniListID",
    "AniListTitle",
    "AniListYear",
    "Color",
    "CountryCode",
    "HttpUrl",
    "YearsActive",
    # Models
    "AiringSchedule",
    "Character",
    "CharacterImage",
    "CharacterName",
    "FuzzyDate",
    "Media",
    "MediaCoverImage",
    "MediaDescription",
    "MediaExternalLink",
    "MediaRank",
    "MediaStreamingEpisode",
    "MediaTag",
    "MediaTitle",
    "MediaTrailer",
    "Relation",
    "Staff",
    "StaffImage",
    "StaffName",
    "Studio",
    # Exceptions
    "CloseError",
    "ConnectError",
    "ConnectTimeout",
    "CookieConflict",
    "DecodingError",
    "HTTPError",
    "HTTPStatusError",
    "InvalidURL",
    "LocalProtocolError",
    "NetworkError",
    "PoolTimeout",
    "ProtocolError",
    "ProxyError",
    "ReadError",
    "ReadTimeout",
    "RemoteProtocolError",
    "RequestError",
    "RequestNotRead",
    "ResponseNotRead",
    "StreamClosed",
    "StreamConsumed",
    "StreamError",
    "TimeoutException",
    "TooManyRedirects",
    "UnsupportedProtocol",
    "WriteError",
    "WriteTimeout",
    "ValidationError",
]
